pub fn initialize(signer: &Pubkey) -> InstructionExpand description
Build an Initialize instruction Creates the Config account with next_message_id = 0
pub fn initialize(signer: &Pubkey) -> InstructionBuild an Initialize instruction Creates the Config account with next_message_id = 0